@@ -20,6 +20,7 @@
 
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
+#include <X11/Xlib.h>
 
 #include <config.h>
 
@@ -180,7 +181,11 @@ release_grabs (void)
         /* Make sure we release grabs */
         gdk_pointer_ungrab(GDK_CURRENT_TIME);
         gdk_keyboard_ungrab(GDK_CURRENT_TIME);
-	gdk_x11_ungrab_server ();
+
+        /* TODO: can we replace this with gdk_x11_ungrab_server ()?
+         * see http://bugzilla.gnome.org/show_bug.cgi?id=550135.
+         */
+	XUngrabServer (GDK_DISPLAY ());
 
         gdk_flush();
 
